@@ -268,8 +268,8 @@ class Backslashes(OutputTest):
 
     def test3(self):
         """ a single \\ without using rawstrings"""
-        self.verify("\ \ ",
-                    "\ \ ")
+        self.verify("\\ \\ ",
+                    "\\ \\ ")
 
     def test4(self):
         """ single line from an apache conf file"""
@@ -296,11 +296,13 @@ class Backslashes(OutputTest):
 
     def test7(self):
         """ a single \\ without using rawstrings plus many NEWLINES"""
-        self.verify("\ \ " + "\n\n\n\n\n\n\n\n\n",
-                    "\ \ " + "\n\n\n\n\n\n\n\n\n")
+        self.verify("\\ \\ " + "\n\n\n\n\n\n\n\n\n",
+                    "\\ \\ " + "\n\n\n\n\n\n\n\n\n")
 
     def test8(self):
-        """ single line from an apache conf file with single quotes and many NEWLINES
+        """
+        Single line from an apache conf file
+        with single quotes and many NEWLINES
         """
 
         self.verify(
@@ -316,17 +318,17 @@ class NonTokens(OutputTest):
 
     def test2(self):
         """hash not in #directives"""
-        self.verify("# \# #5 ",
+        self.verify("# \\# #5 ",
                     "# # #5 ")
 
     def test3(self):
         """escapted comments"""
-        self.verify("  \##escaped comment  ",
+        self.verify("  \\##escaped comment  ",
                     "  ##escaped comment  ")
 
     def test4(self):
         """escapted multi-line comments"""
-        self.verify("  \#*escaped comment \n*#  ",
+        self.verify("  \\#*escaped comment \n*#  ",
                     "  #*escaped comment \n*#  ")
 
     def test5(self):
@@ -794,18 +796,18 @@ class UnicodeDirective(OutputTest):
         self.verify("#unicode latin-1\n1234",
                     u"1234")
 
-        self.verify("#unicode latin-1\n1234",
-                    u"1234")
-        self.verify("#unicode: latin-1\n1234",
-                    u"1234")
-        self.verify("#  unicode  : latin-1\n1234",
-                    u"1234")
+        self.verify("#unicode latin-1\n1234?",
+                    u"1234?")
+        self.verify("#unicode: latin-1\n1234?",
+                    u"1234?")
+        self.verify("#  unicode  : latin-1\n1234?",
+                    u"1234?")
 
-        self.verify(u"#unicode latin-1\n1234",
-                    u"1234")
+        self.verify(u"#unicode latin-1\n1234?",
+                    u"1234?")
 
-        self.verify("#encoding latin-1\n1234",
-                    u"1234")
+        self.verify("#encoding latin-1\n1234?",
+                    u"1234?")
 
 
 class Placeholders_Esc(OutputTest):
@@ -813,27 +815,27 @@ class Placeholders_Esc(OutputTest):
 
     def test1(self):
         """1 escaped placeholder"""
-        self.verify("\$var",
+        self.verify("\\$var",
                     "$var")
 
     def test2(self):
         """2 escaped placeholders"""
-        self.verify("\$var \$_",
+        self.verify("\\$var \\$_",
                     "$var $_")
 
     def test3(self):
         """2 escaped placeholders - back to back"""
-        self.verify("\$var\$_",
+        self.verify("\\$var\\$_",
                     "$var$_")
 
     def test4(self):
         """2 escaped placeholders - nested"""
-        self.verify("\$var(\$_)",
+        self.verify("\\$var(\\$_)",
                     "$var($_)")
 
     def test5(self):
         """2 escaped placeholders - nested and enclosed"""
-        self.verify("\$(var(\$_)",
+        self.verify("\\$(var(\\$_)",
                     "$(var($_)")
 
 
@@ -1824,19 +1826,19 @@ class DefDirective(OutputTest):
     def test13(self):
         """single line #def escaped $placeholders"""
         self.verify(
-            "#def testMeth: \$aFunc(\$anInt)\n- $testMeth -",
+            "#def testMeth: \\$aFunc(\\$anInt)\n- $testMeth -",
             "- $aFunc($anInt) -")
 
     def test14(self):
         """single line #def 1 escaped $placeholders"""
         self.verify(
-            "#def testMeth: \$aFunc($anInt)\n- $testMeth -",
+            "#def testMeth: \\$aFunc($anInt)\n- $testMeth -",
             "- $aFunc(1) -")
 
     def test15(self):
         """single line #def 1 escaped $placeholders + more WS"""
         self.verify(
-            "#def testMeth    : \$aFunc($anInt)\n- $testMeth -",
+            "#def testMeth    : \\$aFunc($anInt)\n- $testMeth -",
             "- $aFunc(1) -")
 
     def test16(self):
@@ -1973,19 +1975,19 @@ inner
     def test8(self):
         """single line #block 1 escaped $placeholders"""
         self.verify(
-            "#block testMeth: \$aFunc($anInt)",
+            "#block testMeth: \\$aFunc($anInt)",
             "$aFunc(1)")
 
     def test9(self):
         """single line #block 1 escaped $placeholders + WS"""
         self.verify(
-            "#block testMeth: \$aFunc( $anInt )",
+            "#block testMeth: \\$aFunc( $anInt )",
             "$aFunc( 1 )")
 
     def test10(self):
         """single line #block 1 escaped $placeholders + more WS"""
         self.verify(
-            "#block testMeth  : \$aFunc( $anInt )",
+            "#block testMeth  : \\$aFunc( $anInt )",
             "$aFunc( 1 )")
 
     def test11(self):
@@ -2148,7 +2150,8 @@ class SetDirective(OutputTest):
 
     def test5(self):
         """#set with a dictionary"""
-        self.verify("""#set $testDict = {'one':'one1','two':'two2','three':'three3'}
+        self.verify("""\
+#set $testDict = {'one':'one1','two':'two2','three':'three3'}
 $testDict.one
 $testDict.two""",
                     "one1\ntwo2")
@@ -2820,14 +2823,16 @@ class ExtendsDirective(OutputTest):
 
     def test1(self):
         """#extends Cheetah.Templates._SkeletonPage"""
-        self.verify("""#from Cheetah.Templates._SkeletonPage import _SkeletonPage
+        self.verify("""\
+#from Cheetah.Templates._SkeletonPage import _SkeletonPage
 #extends _SkeletonPage
 #implements respond
 $spacer()
 """,
                     '<img src="spacer.gif" width="1" height="1" alt="" />\n')
 
-        self.verify("""#from Cheetah.Templates._SkeletonPage import _SkeletonPage
+        self.verify("""\
+#from Cheetah.Templates._SkeletonPage import _SkeletonPage
 #extends _SkeletonPage
 #implements respond(foo=1234)
 $spacer()$foo
@@ -3050,9 +3055,9 @@ class GetVar(OutputTest):               # Template.getVar()
                     "1234")
 
     def test6(self):
-        """$getVar('$') raises ValueError
+        """$getVar('$') raises ValueError or NotFound(LookupError)
         """
-        with self.assertRaises(ValueError):
+        with self.assertRaises((ValueError, LookupError)):
             self.verify("$getVar('$')", "never get here")
 
 
@@ -3067,6 +3072,19 @@ class MiscComplexSyntax(OutputTest):
                     "0")
 
 
+class MatchObject(OutputTest):
+    def test1(self):
+        """re Match objects implement both attribute access and index access;
+        match[2] is equivalent to match.group(2).
+        That confuses NameMapper and requires special handling.
+        """
+        self.verify(
+            r"""#import re
+#set $match = re.match(r'(.*)\s(\(\w+\))', 'test (add)')
+$match.group(2)""",
+            "(add)")
+
+
 class CGI(OutputTest):
     """CGI scripts with(out) the CGI environment and with(out) GET variables.
     """
